==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Aranje labaz',

	// I
	'info_restauration_sauvegarde' => 'Restòwasyon lasòvgad @archive@', # MODIF
	'info_sauvegarde' => 'Sòvgad',
	'info_sauvegarde_reussi_02' => 'Baz-la te fin sovgadé nan @archive@. W kapab',
	'info_sauvegarde_reussi_03' => 'tounyen dèyè okipe',
	'info_sauvegarde_reussi_04' => 'sit a w.',

	// T
	'texte_admin_tech_01' => 'Opsyon nan ka pèmè aw kembe kontni labazdone nan yon fichye ke sere nan repertwar @dossier@. Pa oublye genyen tout repetwar-la @img@, pou sere byen tout limaj ak dokiman ki nan zot atik, zot ki repertwar-la ka kembe azot li mèm.',
	'texte_admin_tech_02' => 'Atansyon: sòvgad-la ke kapab restore SELMAN sou yon sit ki enstalé sou yon mèm vèsyon SPIP. Fòk pa w « vid labaz » po enstalé sòvgad-la apré met nan nivo... Gade <a href="@spipnet@">dokimantasyon SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restore kontni yon sovgad baz-la',
	'texte_restaurer_sauvegarde' => 'Opsyon-nan ki pémè w restore yon sovgad  ki w té fé avan sou baz-la.
 Akoz, fok w plasé fichye an ki kembe sovgad-la nan répertwar 
 @dossier@.
  Tansyon kank w touche fonksyonalité an : <b>tout chanjman, tout bagay ki perdi, se
  définitif.</b>', # MODIF
	'texte_sauvegarde' => 'Sovgad kontni baz-la',
	'texte_sauvegarde_base' => 'Sovgad baz-la'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Aranje labaz',

	// I
	'info_restauration_sauvegarde' => 'Restòwasyon lasòvgad @archive@', # MODIF
	'info_sauvegarde' => 'Sòvgad',
	'info_sauvegarde_reussi_02' => 'Baz-la te fin sovgadé nan @archive@. W kapab',
	'info_sauvegarde_reussi_03' => 'tounyen dèyè okipe',
	'info_sauvegarde_reussi_04' => 'sit a w.',

	// T
	'texte_admin_tech_01' => 'Opsyon nan ka pèmè aw kembe kontni labazdone nan yon fichye ke sere nan repertwar @dossier@. Pa oublye genyen tout repetwar-la @img@, pou sere byen tout limaj ak dokiman ki nan zot atik, zot ki repertwar-la ka kembe azot li mèm.',
	'texte_admin_tech_02' => 'Atansyon: sòvgad-la ke kapab restore SELMAN sou yon sit ki enstalé sou yon mèm vèsyon SPIP. Fòk pa w « vid labaz » po enstalé sòvgad-la apré met nan nivo... Gade <a href="@spipnet@">dokimantasyon SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restore kontni yon sovgad baz-la',
	'texte_restaurer_sauvegarde' => 'Opsyon-nan ki pémè w restore yon sovgad  ki w té fé avan sou baz-la.
 Akoz, fok w plasé fichye an ki kembe sovgad-la nan répertwar 
 @dossier@.
  Tansyon kank w touche fonksyonalité an : <b>tout chanjman, tout bagay ki perdi, se
  définitif.</b>', # MODIF
	'texte_sauvegarde' => 'Sovgad kontni baz-la',
	'texte_sauvegarde_base' => 'Sovgad baz-la',
];
